@@ -21,6 +21,7 @@
 #include "diag.h"
 #include "jit/jit.h"
 #include "lib.h"
+#include "option.h"
 #include "phase.h"
 #include "rt/model.h"
 #include "scan.h"
@@ -1986,6 +1987,19 @@ START_TEST(test_signal34)
 }
 END_TEST
 
+START_TEST(test_issue1195)
+{
+   opt_set_int(OPT_PRESERVE_CASE, 1);
+
+   input_from_file(TESTDIR "/elab/issue1195.vhd");
+
+   tree_t e = run_elab();
+   fail_if(e == NULL);
+
+   fail_if_errors();
+}
+END_TEST
+
 Suite *get_elab_tests(void)
 {
    Suite *s = suite_create("elab");
@@ -2092,6 +2106,7 @@ Suite *get_elab_tests(void)
    tcase_add_test(tc, test_issue1012);
    tcase_add_test(tc, test_issue1017);
    tcase_add_test(tc, test_signal34);
+   tcase_add_test(tc, test_issue1195);
    suite_add_tcase(s, tc);
 
    return s;
